@@ -1,7 +1,7 @@
 package Data::Clean;
 
 our $DATE = '2017-01-14'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,9 +18,9 @@ sub new {
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
     }
-    $self->{code} = eval $cd->{src};
+    $self->{_cd} = $cd;
+    $self->{_code} = eval $cd->{src};
     {
-        $self->{clone_func} = $cd->{clone_func};
         last unless $cd->{clone_func} =~ /(.+)::(.+)/;
         (my $mod_pm = "$1.pm") =~ s!::!/!g;
         require $mod_pm;
@@ -266,14 +266,14 @@ sub _generate_cleanser_code {
 sub clean_in_place {
     my ($self, $data) = @_;
 
-    $self->{code}->($data);
+    $self->{_code}->($data);
 }
 
 sub clone_and_clean {
     no strict 'refs';
 
     my ($self, $data) = @_;
-    my $clone = &{$self->{clone_func}}($data);
+    my $clone = &{$self->{_cd}{clone_func}}($data);
     $self->clean_in_place($clone);
 }
 
@@ -292,7 +292,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.46 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-14.
+This document describes version 0.47 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-14.
 
 =head1 SYNOPSIS
 
